@@ -1,14 +1,21 @@
 package PJob::Client;
-our $VERSION = '0.19';
+our $VERSION = '0.29';
 
 
 
 use Any::Moose;
-use Term::ANSIColor;
+use Term::ANSIColor qw/:constants/;
 use Carp qw/carp croak/;
 use POE qw/Component::Client::TCP/;
 
 $| = 1;
+my $yellow = YELLOW;
+my $bold   = BOLD;
+my $red    = RED;
+my $blue   = BLUE;
+my $reset  = RESET;
+my $green  = GREEN;
+
 has 'server' => (
     is       => 'rw',
     isa      => 'Str',
@@ -27,8 +34,8 @@ has 'job' => (
 );
 
 has '_cqueue' => (
-    is  => 'rw',
-    isa => 'ArrayRef',
+    is      => 'rw',
+    isa     => 'ArrayRef',
     default => sub { [] },
 );
 
@@ -37,7 +44,7 @@ sub BUILD {
     $self->{_queued} = 0;
 }
 
-sub run{
+sub run {
     shift->_run;
 }
 
@@ -55,8 +62,9 @@ sub queue_command {
 
 sub _run {
     my $self = shift;
-    my $sub_for_input = sub {$self->_get_input_interactive(@_)};
-    $sub_for_input = sub { $self->_get_input_queue(@_) } if $self->{_queued};
+    my $sub_for_input = sub { $self->_get_input_interactive(@_) };
+    $sub_for_input = sub { $self->_get_input_queue(@_) }
+      if $self->{_queued};
     my ($server, $port) = $self->_get_remote;
     $self->{_session} = POE::Component::Client::TCP->new(
         RemoteAddress => $server,
@@ -74,6 +82,7 @@ sub _get_remote {
     my $self = shift;
 
     my ($server, $port) = split ':', $self->server, 2;
+
     if (!$self->port) {
         carp "no port specified\n" if !$port;
         $self->port($port);
@@ -91,21 +100,21 @@ sub _get_input_interactive {
     my $self  = shift;
     my $input = $_[ARG0];
     if ($input eq '.') {
-        print ">";
+        print _($bold,$yellow,">");
         my $k = <>;
         chomp $k;
         $_[HEAP]{server}->put($k);
     }
     else {
-        print $input, "\n";
+        $self->_format_and_output($input);
     }
 }
 
 sub _get_input_queue {
     my $self = shift;
-    my ($input,$heap) = @_[ARG0,HEAP];
-    if($input eq '.'){
-        if(! scalar @{$self->_cqueue}){
+    my ($input, $heap) = @_[ARG0, HEAP];
+    if ($input eq '.') {
+        if (!scalar @{$self->_cqueue}) {
             $heap->{server}->put('quit');
             return;
         }
@@ -114,12 +123,11 @@ sub _get_input_queue {
         return unless $command;
         $heap->{server}->put($command);
     }
-    else{
+    else {
         print $input, "\n";
     }
 }
 
-
 sub _disconnected {
     my $self = shift;
 
@@ -129,7 +137,7 @@ sub _disconnected {
 
 sub _server_error {
     my $self = shift;
-    my ($oper,$nexit,$sexit) = @_[ARG0,ARG1,ARG2];
+    my ($oper, $nexit, $sexit) = @_[ARG0, ARG1, ARG2];
     return if $nexit == 0;
     print "Server Error:\n";
     print "\toperation\t$oper\n";
@@ -137,21 +145,55 @@ sub _server_error {
     $_[KERNEL]->yield('shutdown');
 }
 
+sub _{
+    push @_,$reset;
+    return @_;
+}
+
+sub _format_and_output {
+    my ($self,$input) = @_;
+    if($input =~ /^Usage:(.*)$/){
+        print _("Usage:", $bold,$blue,$1,"\n");
+        return;
+    }elsif($input =~/^Job\s+(.*?)\s+:::(\d+)\sstarted\.$/){
+        print _("Job ", $bold,$green,$1,' :::',$2,$reset," started\n");
+        return;
+    }elsif($input =~/Out\t(.*)$/){
+        print _($1,"\n");
+        return;
+    }elsif($input =~/Err\t(.*)$/){
+        print _($yellow,'[stderr] ',$reset,$1,"\n");
+        return;
+    }elsif($input =~/^Job\s+(.*?)\s+:::(\d+)(.*?)(\d+)$/){
+        print _("Job ", $bold,$green,$1,' :::',$2,$reset,$3,$red,$bold,$4,"\n");
+        return;
+    }else{
+        print $input,"\n";
+    }
+}
+
 no Any::Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
     
 PJob::Client -- Simple PJob client for PJob Server
 
+=head1 VERSION
+
+This document describes version 0.29 of PJob::Client
+
 =head1 SINOPISYS
 
     $pc =  PJob::Client->new(server => 'localhost',port => '10086')
                        ->run();
+    $pc =  PJob::Client->new(server => 'localhost:10086')
+            ->queue_command('ls','ps')->run_queue;
 
 =head1 DESCRIPTION
 
@@ -174,12 +216,16 @@ This method will overwrite the port specified by B<server>
     
 run a interative client
 
+=item B<queue_command>
+
+queue some commands into the command queue
+
+=item B<run_queue>
+
+run the commands in the queue
+
 =back
 
-=head1 TODO
-
-Add ANSIColor support
-
 =head1 SEE ALSO
     
 L<POE::Component::Client::TCP>,L<Any::Moose>,L<PJob::Server>
